@@ -3,7 +3,7 @@
 # @Date:   2020-03-10 14:52:05
 # @E-mail: maoyongfan@163.com
 # @Last Modified by:   yongfanmao
-# @Last Modified time: 2020-08-19 14:14:19
+# @Last Modified time: 2020-08-21 15:50:31
 
 from robot.api import logger
 from HelloBikeLibrary.request import Request
@@ -13,7 +13,7 @@ __version__ = "1.0"
 
 class Common(object):
 
-	def __sendCodeV3(self,mobilePhone,env="fat"):
+	def __sendCodeV3(self,mobilePhone,env="uat"):
 		if env == "uat":
 			url = "https://uat-api.hellobike.com/api"
 		else:
@@ -32,12 +32,14 @@ class Common(object):
 		}
 		rep = Request().request_client(url=url,data=data)
 
-	def login_auth_app(self,mobilePhone,env="fat"):
+	def login_auth_app(self,mobilePhone,env="uat"):
 		"""
 			app登陆认证
+			mobilePhone 登陆手机号
+			env 不传默认为uat
 			返回token,guid
 		"""
-		self.__sendCodeV3(mobilePhone)
+		self.__sendCodeV3(mobilePhone,env)
 		if env == "uat":
 			app_url = "https://uat-api.hellobike.com/auth"
 		else:
@@ -75,4 +77,5 @@ class Common(object):
 if __name__ == '__main__':
 	com = Common()
 	print(com.login_auth_app("12010002002",env="uat"))
+	# print(com.login_auth_app("12010060001",env="uat"))
 
